pub struct TranslationPart {
pub entry: &'static str,
pub source: Option<&'static str>,
}Expand description
One optional alchemy source and the entry point a host calls.
Fields
entry: &'static strThe entry point a host calls.
source: Option<&'static str>The source text, or None for an entry supplied by alchemy.